==> spip_3.0.21.orig.tar.xz: spip/plugins-dist/compagnon/lang/compagnon_nl.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/compagnon?lang_cible=nl
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) return;

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// C
	'c_accueil_bienvenue' => 'Welkom @nom@ !',
	'c_accueil_configurer_site' => 'Je site configureren',
	'c_accueil_configurer_site_texte' => 'Om te beginnen moet je je site een naam geven.
		Momenteel is het  « @nom@ » genoemd. De naam van het site wordt op het top van dit pagina aangeduid.
		Klik erop om zijn naam te veranderen maar ook om er een logo en een slogan bij te geven.',
	'c_accueil_publication' => 'Publiceer !',
	'c_accueil_publication_texte' => 'Om een pagina te publiceren moet je een artikel scheppen.
		Hiervoor moet je tenminste een rubriek aanmaken. Je mag dat doen in het « Uitgave » menu door op « Rubrieken » te klikken.',
	'c_accueil_texte' => 'Je bent pas in het privé-ruimte van SPIP binnengekomen.',
	'c_accueil_texte_revenir' => '		Deze pagina wijst je het laatste editoriaal activiteit op je site aan.
		Je kan hier altijd terugkomen door op het huisje te klikken die zich aan de bovenkant
		juist onder je naam bevindt.',
	'c_article_redaction' => 'De redactie van het artikel is aan de gang.',
	'c_article_redaction_redacteur' => 'De redactie van het artikel is aan de gang.',
	'c_article_redaction_redacteur_texte' => 'Om je artikel aan de sitebeheerders en aan de anderen redacteurs voor te stellen,
		klik op  « in redactie » in het bijliggende kader en selecteer dan  « voorgesteld voor evaluatie » (+ Wijzigen).',
	'c_article_redaction_texte' => 'Om het artikel op het publiek site te publiceren moet zijn statuut veranderd worden.
		In het bijliggende kader, wijzig « in redactie » naar « inline geplaatst ».',
	'c_articles_creer' => 'Hoe een artikel aanmaken ?',
	'c_articles_creer_texte' => 'Je zal een artikel vanaf dit pagina kunnen aanmaken
		zodra je site tenminste een rubriek zal bevatten.
		Maak een rubriek aan vanaf het « Uitgave » menu, klik daar op « Rubrieken ».',
	'c_job' => 'Het lijst van werken',
	'c_job_texte' => 'Op deze pagina vind je het lijst van de volgende onderhoudstaken van SPIP.
		De taken worden op regelmatige termijnen uitgevoerd of af en toe voor zwaardere onderhandelingen gevraagd door plugins, zoals het massa uitzenden van e-mails.',
	'c_rubrique_publier' => 'Maak een artikel aan',
	'c_rubrique_publier_texte' => 'Een rubriek wordt maar op het publiek site zichtbaar op het moment waar ze tenminste een gepubliceerde element bevat. Bijvoorbeeld een gepubliceerde artikel. 
                  Maak dus een artikel aan. Dit mag je vanaf hier beginnen, onder de beschrijving van het rubriek.',
	'c_rubriques_creer' => 'Maak een eerste rubriek aan !',
	'c_rubriques_creer_texte' => 'De rubrieken vormen het basisstructuur van je site. In ieder rubriek kan je artikels aanmaken.
		Begin met het aanmaken van een eerste rubriek.',

	// E
	'explication_activer_compagnon' => 'De metgezel geeft raden op enkele paginas van het privé-ruimte om aan het in hand nemen van SPIP  te helpen. Wil je de metzegel activeren ?',
	'explication_reinitialiser_compagnon' => 'De boodschappen al gelezen door een auteur worden daarna niet meer getoond.
			Wil je die boodschappen resetten ?',

	// L
	'label_activer_compagnon' => 'De metgezel activeren ?',
	'label_reinitialiser_compagnon' => 'De boodschappen van de metgezel resetten ?',

	// O
	'ok' => 'OK',
	'ok_bien' => 'Goed !',
	'ok_jai_compris' => 'Ik heb begrepen !',
	'ok_merci' => 'Dank je',
	'ok_parfait' => 'Prima !',

	// R
	'reinitialisation' => 'Reset',
	'reinitialisation_ok' => 'De reset is gedaan.',
	'reinitialiser' => 'Resetten',
	'reinitialiser_moi' => 'Ja, alleen die dat ik al gelezen heb.',
	'reinitialiser_tous' => 'Ja, voor alle auteurs.',

	// T
	'titre_compagnon' => 'De Metgezel',
	'titre_page_configurer_compagnon' => 'De Metgezel configureren'
);

?>

==> spip_3.1.4.orig.tar.xz: spip/plugins-dist/compagnon/lang/compagnon_nl.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/compagnon?lang_cible=nl
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// C
	'c_accueil_bienvenue' => 'Welkom @nom@ !',
	'c_accueil_configurer_site' => 'Je site configureren',
	'c_accueil_configurer_site_texte' => 'Om te beginnen moet je je site een naam geven.
		Momenteel is het  « @nom@ » genoemd. De naam van het site wordt op het top van dit pagina aangeduid.
		Klik erop om zijn naam te veranderen maar ook om er een logo en een slogan bij te geven.',
	'c_accueil_publication' => 'Publiceer !',
	'c_accueil_publication_texte' => 'Om een pagina te publiceren moet je een artikel scheppen.
		Hiervoor moet je tenminste een rubriek aanmaken. Je mag dat doen in het « Uitgave » menu door op « Rubrieken » te klikken.',
	'c_accueil_texte' => 'Je bent pas in het privé-ruimte van SPIP binnengekomen.',
	'c_accueil_texte_revenir' => '		Deze pagina toont je het laatste editoriaal activiteit op je site.
		Je kunt hier altijd terugkomen door op het huisje te klikken dat zich aan de bovenzijde
		bevindt, juist onder je naam.',
	'c_article_redaction' => 'De redactie van het artikel is aan de gang.',
	'c_article_redaction_redacteur' => 'De redactie van het artikel is aan de gang.',
	'c_article_redaction_redacteur_texte' => 'Om je artikel aan de sitebeheerders en aan de anderen redacteurs voor te stellen,
		klik op  « in redactie » in het bijliggende kader en selecteer dan  « voorgesteld voor evaluatie » (+ Wijzigen).',
	'c_article_redaction_texte' => 'Om het artikel op het publiek site te publiceren moet zijn statuut veranderd worden.
		In het bijliggende kader, wijzig « in redactie » naar « inline geplaatst ».',
	'c_articles_creer' => 'Hoe een artikel aanmaken ?',
	'c_articles_creer_texte' => 'Je zal een artikel vanaf dit pagina kunnen aanmaken
		zodra je site tenminste een rubriek zal bevatten.
		Maak een rubriek aan vanaf het « Uitgave » menu, klik daar op « Rubrieken ».',
	'c_job' => 'Het lijst van werken',
	'c_job_texte' => 'Op deze pagina vind je het lijst van de volgende onderhoudstaken van SPIP.
		De taken worden op regelmatige termijnen uitgevoerd of af en toe voor zwaardere onderhandelingen gevraagd door plugins, zoals het massa uitzenden van e-mails.',
	'c_rubrique_publier' => 'Maak een artikel aan',
	'c_rubrique_publier_texte' => 'Een rubriek wordt maar op het publiek site zichtbaar op het moment waar ze tenminste een gepubliceerde element bevat. Bijvoorbeeld een gepubliceerde artikel. 
                  Maak dus een artikel aan. Dit mag je vanaf hier beginnen, onder de beschrijving van het rubriek.',
	'c_rubriques_creer' => 'Maak een eerste rubriek aan !',
	'c_rubriques_creer_texte' => 'De rubrieken vormen het basisstructuur van je site. In ieder rubriek kan je artikels aanmaken.
		Begin met het aanmaken van een eerste rubriek.',
	'c_sites_creer' => 'Hoe je een site maakt of importeert?',
	'c_sites_creer_texte' => 'Vanaf deze pagina kun pas een site maken of importeren
		wanneer er tenminste één rubriek in de site bestaat.
		Je kunt hem aanmaken via het menuVous pouvez la créer depuis le menu « Redactie » en vervolgens « Rubrieken ».',

	// E
	'explication_activer_compagnon' => 'De metgezel geeft raden op enkele paginas van het privé-ruimte om aan het in hand nemen van SPIP  te helpen. Wil je de metzegel activeren ?',
	'explication_reinitialiser_compagnon' => 'De boodschappen al gelezen door een auteur worden daarna niet meer getoond.
			Wil je die boodschappen resetten ?',

	// L
	'label_activer_compagnon' => 'De metgezel activeren ?',
	'label_reinitialiser_compagnon' => 'De boodschappen van de metgezel resetten ?',

	// O
	'ok' => 'OK',
	'ok_bien' => 'Goed !',
	'ok_jai_compris' => 'Ik heb begrepen !',
	'ok_merci' => 'Dank je',
	'ok_parfait' => 'Prima !',

	// R
	'reinitialisation' => 'Reset',
	'reinitialisation_ok' => 'De reset is gedaan.',
	'reinitialiser' => 'Resetten',
	'reinitialiser_moi' => 'Ja, alleen die dat ik al gelezen heb.',
	'reinitialiser_tous' => 'Ja, voor alle auteurs.',

	// T
	'titre_compagnon' => 'De Metgezel',
	'titre_page_configurer_compagnon' => 'De Metgezel configureren'
);

?>
